@@ -15,6 +15,7 @@ public:
     explicit options(QWidget *parent = 0);
     ~options();
     Ui::options *ui;
+
 public slots:
     void load_cfg();
     void save_cfg();
@@ -22,11 +23,19 @@ public slots:
 
     void psx4m_hwa_block();
     void createCfg();
+    void memory_card_1();
+    void memory_card_2();
+    void show();
 
 protected:
     void hideEvent(QHideEvent *);
 
-
+private:
+    QString m_MemoryCard1;
+    QString m_MemoryCard2;
+#ifdef Q_WS_MAEMO_5
+    QString GetMemoryCardName();
+#endif
 };
 
 #endif // OPTIONS_H
